<?php

namespace Drupal\book_access\Entity;

use Drupal\Core\Config\Entity\ConfigEntityBase;

/**
 * Defines the Book access defaults config entity.
 *
 * @package Drupal\book_access\Entity
 *
 * @ConfigEntityType(
 *   id = "book_access_defaults",
 *   label = @Translation("Book Access Defaults"),
 *   config_prefix = "book_access_defaults",
 *   admin_permission = "administer book access",
 *   entity_keys = {
 *     "id" = "id",
 *     "label" = "name",
 *     "uuid" = "uuid"
 *   },
 *   config_export = {
 *     "id",
 *     "label",
 *     "uuid",
 *     "grant_type",
 *     "role_id",
 *     "grants",
 *   }
 * )
 */
class BookAccessDefaults extends ConfigEntityBase implements BookAccessDefaultsInterface {

  /**
   * The grant type: Author or role.
   *
   * @var string
   */
  protected $grant_type;

  /**
   * The role_id if for a role.
   *
   * @var string
   */
  protected $role_id;

  /**
   * The list of grants.
   *
   * @var array
   */
  protected $grants;

  /**
   * Get the type.
   *
   * @return string
   *   The type of grant: author or role.
   */
  public function getGrantType() {
    return $this->grant_type;
  }

  /**
   * Get the role id.
   *
   * @return string
   *   The role_id if for a role.
   */
  public function getRoleId() {
    return $this->role_id;
  }

  /**
   * Get the list of grants.
   *
   * @return array
   *   The list of grants.
   */
  public function getGrants() {
    return $this->grants;
  }

  /**
   * {@inheritdoc}
   */
  public function calculateDependencies() {
    parent::calculateDependencies();
    $this->addDependency('module', 'user');
    if (isset($this->role_id) && $this->role_id !== '__author__') {
      $this->addDependency('config', "user.role.{$this->role_id}");
    }

    return $this;
  }

}
